glifo_categoria = {
    "AL": "activador", "EN": "receptor", "IL": "estabilizador",
    "OZ": "disonante", "UM": "acoplador", "RA": "resonador",
    "SHA": "latente", "VAL": "expansivo", "NUL": "contractivo",
    "THOL": "autoorganizador", "ZHIR": "mutante", "NAV": "transicional",
    "REMESH": "recursivo"
}